@@ -14,7 +14,7 @@ function(traits){
   d <- eig_X
   p <- length (d)
   n <- nrow(X)
-  INT<-sum((d-1)^2)/(p-1)
+  INT<-sum((d-1)^2)/(p)
   INT.c<-(INT-((p-1)/n))
   pref="PINT = "
   pref2="RelPINT = "
