@@ -1,5 +1,5 @@
 pintsc.jack <-
-function (traits,control=NA,n.remove=1){
+function (traits,control=NA,n.remove=1,verbose=FALSE){
   INT = list()
   INTC = list()
 
@@ -89,6 +89,16 @@ length(INT)
 )
 row.names(outs)<-names
 colnames(outs)<-c("PINTSC","PINTSC.C")
+
+if(verbose==TRUE)
+	{
+	outs<-list(outs)
+	outs[[2]]<-Intphen1
+	outs[[3]]<-Intphen2
+	names(outs)<-c("Summary","Resampled PINTSC","Resampled PINTSC.C")
+	}
+
+
 outs
 
 }
